@@ -1,5 +1,3 @@
-
-
 class MCServerInteractionException(Exception):
     pass
 
@@ -18,3 +16,11 @@ class ServerRunningException(MCServerInteractionException):
 
 class UnsupportedVersionException(MCServerInteractionException):
     pass
+
+
+class NotAWorldFolderException(MCServerInteractionException):
+    pass
+
+
+class WorldExistsException(MCServerInteractionException):
+    pass
