@@ -1,6 +1,6 @@
 import asyncio
-from asyncio.subprocess import Process
-from typing import Callable, Optional
+import logging
+from typing import Callable
 
 import psutil
 
@@ -13,35 +13,44 @@ class Callback:
         for func in self.installed_callbacks:
             try:
                 await func(*args, **kwargs)
-            except Exception:
+            except Exception as e:
+                print(e)
                 self.installed_callbacks.remove(func)
 
+    def __len__(self):
+        return len(self.installed_callbacks)
+
     def add_callback(self, func: Callable):
         self.installed_callbacks.append(func)
 
 
 class Callbacks:
-    stdout = Callback()
-    exit = Callback()
-    error_occurred = Callback()
+    def __init__(self):
+        self.stdout = Callback()
+        self.exit = Callback()
+        self.error_occurred = Callback()
 
 
 class ServerProcess:
-    process: Optional[Process]
-    psutil_proc: Optional[psutil.Process]
-    callbacks = Callbacks()
-    system_metrics: dict = {}
-    num_cpus = psutil.cpu_count()
 
     async def start(self, command, cwd):
         self.process = await asyncio.create_subprocess_exec(
-            *command, stdout=asyncio.subprocess.PIPE,
+            *command,
+            stdout=asyncio.subprocess.PIPE,
             stderr=asyncio.subprocess.PIPE,
             stdin=asyncio.subprocess.PIPE,
-            cwd=cwd
+            cwd=cwd,
         )
         self.psutil_proc = psutil.Process(self.process.pid)
 
+    def __init__(self, server_name: str):
+        self.logger = logging.getLogger(f"MCServerInteraction.{self.__class__.__name__}:{server_name}")
+        self.callbacks = Callbacks()
+        self.system_metrics: dict = {}
+        self.num_cpus = psutil.cpu_count()
+        self.process = None
+        self.psutil_proc = None
+
     async def read_output(self):
         while self.is_running():
             output = await self.process.stdout.readline()
@@ -49,10 +58,13 @@ class ServerProcess:
                 output = output.decode("utf-8")
                 output = output.rstrip("\n")
                 await self.callbacks.stdout(output)
-        await self.callbacks.exit(self.process.returncode, await self.process.stdout.read())
+        await self.callbacks.exit(
+            self.process.returncode, await self.process.stdout.read()
+        )
         self.psutil_proc = None
 
     def kill(self):
+        self.logger.info("Killing process")
         self.process.kill()
         self.psutil_proc = None
 
@@ -75,7 +87,7 @@ class ServerProcess:
             "memory": {
                 "total": memory_system.total,
                 "used": memory_system.used,
-                "server": memory_server.uss
-            }
+                "server": memory_server.uss,
+            },
         }
         return self.system_metrics
